@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007 Marylene Ysmal <wiidevel@stacktic.org>
+ * Copyright (C) 2007-2008 Marylene Ysmal <wiidevel@stacktic.org>
  *
  * pageWiimote.c (TransferMii)
  *
@@ -342,6 +342,8 @@ void onDownloadButton(void)
 	gtk_widget_destroy(chooserDialog);
 }
 
+void update(void);
+
 void onUploadFileButton(void)
 {
 	GtkTreeSelection *selection;
@@ -381,7 +383,9 @@ void onUploadFileButton(void)
 	else
 		updateStatusBar("mii not added");
 	gtk_widget_destroy(chooserDialog);
-	onSelectionChanged();
+	
+	/*onSelectionChanged();*/
+	update();
 }
 
 void onDeleteButton(void)
@@ -646,3 +650,50 @@ void onSelectionChanged(void)
 	else
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sexRadioMale), TRUE);
 }
+
+void update(void) {
+	int slot;
+	char buffMiiName[MII_NAME_LENGTH_CHAR+1];
+	char buffMiiCreator[MII_CREATOR_LENGTH_CHAR+1];
+	unsigned char mactmp[3];
+	char labtmp[23+9+9];
+	
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter selected_row;
+
+	selection=gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
+	if(!wm_read || 
+	   !gtk_tree_selection_get_selected(selection, &model, &selected_row))
+		return;
+
+	slot=((*gtk_tree_model_get_string_from_iter(model,&selected_row))-'0'+1);
+
+	gtk_widget_set_sensitive(downloadButton, TRUE);
+	gtk_widget_set_sensitive(uploadFileButton, TRUE);
+	gtk_widget_set_sensitive(deleteButton, TRUE);
+	
+	gtk_widget_set_sensitive(nameEntry, TRUE);
+	gtk_widget_set_sensitive(creatorEntry, TRUE);
+	gtk_widget_set_sensitive(sexRadioFemale, TRUE);
+	gtk_widget_set_sensitive(sexRadioMale, TRUE);	
+
+	getMiiMacAddress(mactmp, slot);
+	snprintf(labtmp, 40, "Current mac address : 00:17:ab:%2x:%2x:%2x", mactmp[0], mactmp[1], mactmp[2]);
+	gtk_label_set_text(GTK_LABEL(macLabel), labtmp);
+	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wiiMacCheck)))
+		gtk_widget_set_sensitive(changeMacButton, FALSE);
+	else
+		gtk_widget_set_sensitive(changeMacButton, TRUE);
+
+	getMiiNameAscii(buffMiiName, slot);
+	gtk_entry_set_text(GTK_ENTRY(nameEntry), buffMiiName);
+	
+	getMiiCreatorAscii(buffMiiCreator, slot);
+	gtk_entry_set_text(GTK_ENTRY(creatorEntry), buffMiiCreator);	
+
+	if(getMiiSex(slot) == 'F')
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sexRadioFemale), TRUE);
+	else
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sexRadioMale), TRUE);
+}
